@@ -41,8 +41,6 @@
 
 #define KITEMMODELS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KITEMMODELS_NO_DEPRECATED) && !defined(KITEMMODELS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KITEMMODELS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KITEMMODELS_NO_DEPRECATED
-#  define KITEMMODELS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KITEMMODELS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef KITEMMODELS_NO_DEPRECATED_WARNINGS
 #  define KITEMMODELS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KITEMMODELS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KITEMMODELS_DEPRECATED_WARNINGS_SINCE KITEMMODELS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KITEMMODELS_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KITEMMODELS_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KITEMMODELS_DEPRECATED
-#  define KITEMMODELS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KITEMMODELS_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KITEMMODELS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KITEMMODELS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KITEMMODELS_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
